Enum ColorSpace
enum ColorSpace
Variants
-
YCbCr Standard color space for photographic content. Usually the best choice. This library always uses full-resolution color (4:4:4). This library will automatically choose between BT.601 or BT.709.
-
RGB RGB channels are encoded without colorspace transformation. Usually results in larger file sizes, and is less compatible than
YCbCr. Use only if the content really makes use of RGB, e.g. anaglyph images or RGB subpixel anti-aliasing.
Implementations
impl Clone for ColorSpace
fn clone(self: &Self) -> ColorSpace
impl Copy for ColorSpace
impl Debug for ColorSpace
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ColorSpace
impl RefUnwindSafe for ColorSpace
impl Send for ColorSpace
impl Sync for ColorSpace
impl Unpin for ColorSpace
impl UnsafeUnpin for ColorSpace
impl UnwindSafe for ColorSpace
impl<T> Any for ColorSpace
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ColorSpace
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ColorSpace
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ColorSpace
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ColorSpace
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ColorSpace
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ColorSpace
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ColorSpace
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ColorSpace
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>